All language subtitles for Bajillion Dollar Properties s01e09 Make Partner 2.eng

af Afrikaans
ak Akan
sq Albanian
am Amharic
ar Arabic
hy Armenian
az Azerbaijani
eu Basque
be Belarusian
bem Bemba
bn Bengali
bh Bihari
bs Bosnian
br Breton
bg Bulgarian
km Cambodian
ca Catalan
ceb Cebuano
chr Cherokee
ny Chichewa
zh-CN Chinese (Simplified)
zh-TW Chinese (Traditional)
co Corsican
hr Croatian
cs Czech
da Danish
en English
eo Esperanto
et Estonian
ee Ewe
fo Faroese
tl Filipino
fi Finnish
fr French
fy Frisian
gaa Ga
gl Galician
ka Georgian
de German
el Greek
gn Guarani
gu Gujarati
ht Haitian Creole
ha Hausa
haw Hawaiian
iw Hebrew
hi Hindi
hmn Hmong
hu Hungarian
is Icelandic
ig Igbo
id Indonesian
ia Interlingua
ga Irish
it Italian
ja Japanese
jw Javanese
kn Kannada
kk Kazakh
rw Kinyarwanda
rn Kirundi
kg Kongo
ko Korean
kri Krio (Sierra Leone)
ku Kurdish
ckb Kurdish (Soranรฎ)
ky Kyrgyz
lo Laothian
la Latin
lv Latvian
ln Lingala
lt Lithuanian
loz Lozi
lg Luganda
ach Luo
lb Luxembourgish
mk Macedonian
mg Malagasy
ms Malay
ml Malayalam
mt Maltese
mi Maori
mr Marathi
mfe Mauritian Creole
mo Moldavian
mn Mongolian
my Myanmar (Burmese)
sr-ME Montenegrin
ne Nepali
pcm Nigerian Pidgin
nso Northern Sotho
no Norwegian
nn Norwegian (Nynorsk)
oc Occitan
or Oriya
om Oromo
ps Pashto
fa Persian
pl Polish
pt-BR Portuguese (Brazil)
pt Portuguese (Portugal)
pa Punjabi
qu Quechua
ro Romanian
rm Romansh
nyn Runyakitara
ru Russian
sm Samoan
gd Scots Gaelic
sr Serbian
sh Serbo-Croatian
st Sesotho
tn Setswana
crs Seychellois Creole
sn Shona
sd Sindhi
si Sinhalese
sk Slovak
sl Slovenian
so Somali
es Spanish
es-419 Spanish (Latin American)
su Sundanese
sw Swahili
sv Swedish
tg Tajik
ta Tamil
tt Tatar
te Telugu
th Thai
ti Tigrinya
to Tonga
lua Tshiluba
tum Tumbuka
tr Turkish
tk Turkmen
tw Twi
ug Uighur
uk Ukrainian
ur Urdu
uz Uzbek
vi Vietnamese
cy Welsh
wo Wolof
xh Xhosa
yi Yiddish
yo Yoruba
zu Zulu

Original subtitles

Victoria: Previously on "Bajillion Dollar Properties"...

Dean: In eight weeks time, I'm going to take on...

a partner here at Platinum.

Victoria: My whole life has been building up to this moment.

Amir: Man! This is some "Game of Thrones" shit.

Dean: Glenn, I need you to be my eyes and ears among them.

Glenn: If you want me to be your mole at Platinum,

then I'll attach myself to your cheek like you are Robert De Niro.

This algorithm

is going to determine who becomes partner

by the end of the day.

Victoria: Since when does Glenn

have anything to do with this?

Glenn: You have until 6:30.

??

I suggest you take this time to continue selling.

Chelsea: Just two more hours to make a sale

and clinch the partnership.

Baxter: Our very future comes down to this very moment.

??

Amir: We have only two hours to make a final sale

before "D" chooses a partner.

Like a gift from God, I get a call from a new client

who's interested in a pocket listing I have in Encino.

He's NFL superstar Jumbo Haynes.

Jumbo is gonna be the size of my commission

when I close this thing.

-Jumbo: Ryan? -Amir: No, it's Amir.

-Jumbo: Ryan? -Amir: Amir.

-Jumbo: Amir. -Amir: Amir.

Jumbo: Pleasure to meet you, as well, Amir.

How's it going? -Amir: Yeah.

Jumbo: Jumbo Haynes.

-Amir: Yeah. -Jumbo: Left guard.

Three Super Bowls.

Six concussions.

Two ex-wives. One wife.

-Amir: Got it, Jumbo. -Jumbo: Yeah, that's me.

Amir: Got it the first time...and the ninth time.

Jumbo: This is a beautiful house.

??

Amir: The view's actually -- the views are --

Jumbo: The view is astounding. Which room is yours?

Amir: I don't live here, Jumbo.

-Jumbo: You don't live here? -Amir: No, Jumbo.

Jumbo: Okay, so we just wandered through

some stranger's house together?

Amir: We wandered through the house of

someone who is listing their house to sell

'cause you want to buy a house, Jumbo.

Jumbo: I want to buy a house, Jumbo. Correct.

Yes. I'll take it. -Amir: Yeah?

-Jumbo: Yeah. -Amir: You got a deal.

Fuck yeah! Partnership, here I come.

Jumbo: So, I noticed there's only one kitchen.

Amir: Uh, that is pretty standard

that there's one kitchen per house.

Jumbo: I like a little kit--

like, a mini, tiny kitchen in the bathroom.

Everyone always says, "You got to shit where you eat."

That's the expression, right?

Amir: No, I think the expression is, "Don't shit where you eat,"

Jumbo, and it's a metaphor.

It means don't, like, hook up with people at work.

Jumbo: Oh, I would never hook up with people at work.

I'm straight, and everyone I work with is a male.

And, plus, I have two ex-wives and one wife.

-Amir: So you're married. -Jumbo: I am currently married.

About to have three ex-wives.

Amir: Well, let met tell you something.

This is gonna be the perfect bachelor pad

for you to bring any girls you want,

have your crazy NFL parties after.

-Jumbo: [ Laughs ] -Amir: So?

Jumbo: Like fat girls.

Amir: Whatever type of girls.

Jumbo: Skinny girls.

Man, what other types of girls are there?

Amir: Young girls.

Jumbo: Oh, hey. Not again.

Amir: Not too -- not -- not too young.

Jumbo: I fucked a 15-year-old once, but I was 15, as well.

Amir: Okay, well, that's legal, then, Jumbo. That's fine.

-Jumbo: How come? -Amir: How come you can fuck --

Jumbo: I'm not any different now than I was when I was 15.

Amir: I hope he's better at signing papers

than he is at avoiding head trauma.

We got a deal, right? -Jumbo: I'll take it.

Amir: I'm so proud of you that you just agreed to buy this home

and you did it and we finally did it,

so let's call your lawyer,

and let's -- let's -- let's make this --

Jumbo: [ Laughing ]

This is amazing. Yeah.

-Amir: You got a deal. -Jumbo: How much?

-Amir: $8 million. -Jumbo: [ Chuckles ]

I'm sorry. My signing bonus was only $4 million this year.

-Amir: Oh. -Jumbo: Yeah, so --

And I have a lien on my other house from doctor's bills.

Amir: Oh. Oh, man.

Jumbo: Jumbo Haynes.

Amir: You're having one of your weird --

Jumbo: Three Super Bowl rings. Five concussions.

Two ex-wives.

One wife. -Amir: One wife.

-Jumbo: 6'2". -Amir: Jumbo!

Jumbo: What?! What?!

Amir: Fu-u-u-u-ck!

Ugh!

Jumbo: Wait.

Did you say...

Excuse me. -Amir: What?

Jumbo: I'm here to see a tour of the house.

Amir: Fucking leave!

Jumbo: Ow!

Why'd that hurt?

I'm an NFL player.

Amir: I'd love to give Jumbo another concussion.

??

Baxter: Andrew and I called every client/booty call

we have ever had. -Andrew: And holy shit,

one of our clients wants to put in an offer

on a stale, old listing.

-Baxter: Glenn, Glenn, Glenn. -Andrew: Come on, come on.

-Baxter: Sit in the chair. -Andrew: Sit, sit, sit, sit.

Baxter: We need you to pretend to be our client.

Andrew: You're our client. You're our client.

-Baxter: Hey. Hey. -Katie: Hi, Baxter. Hi.

-Baxter: Hi, Katie. -Andrew: Hi!

Baxter: We have forced Glenn to help

by pretending to be a rival client...

Andrew: So we can drive up the sale price in a bidding war.

Andrew: It's really convenient, actually, that you came in.

Baxter: Yeah. Um...

Andrew: Because mister -- I'm sorry. Your name again?

-Glenn: S-Scotty Piping. -Andrew: Scotty Piping.

Baxter: Scotty Piping, meet Katie O'Brien.

-Glenn: Hi. -Katie: Katie O'Brien.

It's so nice to meet you. -Glenn: Nice to meet you.

Baxter: Um, Mr. Piping, actually,

is also looking to buy a home, and he also really loves

the mansion in Trousdale Estates. So --

-Andrew: Loves it. -Katie: Oh.

Andrew: He was literally just about to put in an offer.

-Katie: Ooh, gosh. -Baxter: Yeah, we weren't 100% on --

-Katie: That's so awkward. -Baxter: I know.

Andrew: This is great, though, that you're both here,

'cause we can do an old-fashioned, uh, bid off.

Baxter: Yeah, this -- It used to happen like this all the time.

And, actually, it's much quicker.

You don't have to deal with all the paperwork

and calling people and relaying messages.

That's how we got in this situation in the first place.

Katie: Well, I trust you guys.

You know what you're doing. -Andrew: Thank you. Thank you.

Baxter: Yeah, no, this happens all the time.

So we're just gonna do an old-timey face-to-face bid off.

Andrew: You go ahead and do the honors

of throwing in the initial bid.

Katie: Um, 17.25.

-Baxter: 17.25. -Andrew: Wow. Okay.

Baxter: Yeah, so we just need --

Andrew: Lower than the asking price, by the way.

Glenn: Considering everything that I know

about this property already, I'm prepared to come in at 15.5.

Baxter: 15.5?

Andrew: No, no, no! Other way, Glenn!

-Baxter: 15.5. Okay. -Katie: That is great.

That is crazy. -Baxter: No.

Katie: Whoop. Signed, sealed, and delivered.

Baxter: No, he was -- he was an accident.

Andrew: Well, hold on one second, because that's, uh...

Okay. All right.

You've got to go higher.

Baxter: I look -- Did you say this was gold?

-Andrew: It's 17.5. You go up. -Glenn: Oh, I know.

Andrew: And remember, you have unlimited funds.

Glenn: I got it. I got it.

Andrew: Get in the game, dude.

All right? Oh, yeah, so he wa--

Mr. Piping did, uh, misunderstand.

You were talking about a different house.

Glenn: Yeah. I have unlimited funds.

-Katie: Wow. -Glenn: Yeah, my daddy

was one of the first astronauts, so...

Baxter: And he just has unlimited funds, and --

-Katie: He's still alive? -Glenn: Yeah. Yeah.

Yeah, he's kept in a casket, but he's alive.

Baxter: This scam is never supposed to involve

astronaut vampires.

Glenn: With my unlimited funds and my initial offer of 15.5,

I'm ready to go up to $40 million.

Katie: Oh, well, that -- I mean, that is -- That is way above --

Baxter: No, he's accidentally offered too much.

-Andrew: Jesus. -Katie: No. Thank you so much.

It was nice to meet you. -Baxter: No. Don't. No.

Katie. -Katie: Thank you.

Baxter: He's accidentally offered too much.

-Andrew: It was so clear. -Glenn: I got the house.

Baxter: You idiot.

Glenn: You gave me unlimited funds.

Baxter: Right from the bat -- Scotty Piping?

-Andrew: Piping? -Glenn: I panicked.

Baxter: Can you just say your own name? Any name?

Andrew: You could've said George.

Baxter: They don't know. Name another name right now.

One, two, three.

Glenn: Anthony Pordane.

Baxter: Name a normal name on three.

One, two, three.

Glenn: Barack Jo..binamock.

Baxter: Glenn is the fucking worst.

Andrew: Garbage.

??

Chelsea: I was racking my brain

to find a house to sell in the next hour.

Then it occurred to me Dean would be just as impressed

if I scored a huge listing.

So I headed to an estate owned by old theater director

and nudie-magazine publisher Don DiMello.

Every other potential agent has been scared away

for some reason, but Chelsea don't scare easily.

Don: You're exactly what I described

when they asked me what I wanted in a Realtor.

-Chelsea: Really? -Don: Yes. Precisely.

Chelsea: I'm flattered. [ Chuckles ]

Don: Right down to the height and the legs and the shoes --

it's all perfect. [ Laughs ] -Chelsea: Oh.

Don: Wow.

You just wandered in on your own?

You're gorgeous. Gorgeous, gorgeous, gorgeous.

Chelsea: I have to say, you have a beautiful estate here.

Don: Yes.

??

Chelsea: Well, it's a wonderful space for entertaining. The indoor --

-Don: The house has one bathroom. -Chelsea: Mm.

-Don: I did that very intentionally. -Chelsea: Why?

Don: I want to know who's going to the bathroom and when.

-Chelsea: Why? -Don: I want to have complete control over it.

-Chelsea: Oh. -Don: I don't want people to feel like,

"Oh, this one's in use? I'll go down the hall and use another one."

There isn't another one.

You got to use this one

and this one only. -Chelsea: Oh.

Don: And you got to ask me if you want to use it.

-Chelsea: Oh. Well -- -Don: It's got a zoo.

It's mostly dogs now.

A lot of the animals have escaped from the zoo.

They should've stayed.

Anyway, take note of that if you're thinking of escaping.

What were you saying?

Chelsea: I can see the house means a lot to you.

Don: It means an awful lot to me.

Chelsea: I'm sure it'll be difficult for you to part with.

Don: Yeah. What do you mean by that?

Chelsea: When you sell the home.

Don: Oh, yes, I'm not gonna part with it.

Don: I'm gonna sell the house, and then I'm gonna stay here.

I'm gonna keep on living in it even after I've sold it.

That's the plan. They didn't tell you that?

Chelsea: No one told me that!

-Don: Yeah. -Chelsea: Can I -- Can I have a drink?

-Don: Would you like a drink? -Chelsea: Yes.

Don: Be more than happy.

That's, uh -- that's okay.

Chelsea: I want to make this work.

Um, this location is gorgeous.

Don: You know what? I'm not gonna have any.

That's for you.

Chelsea: Um...I actually forgot I, uh -- I quit.

I quit drinking.

Don: You don't want to have a sip?

Chelsea: No, I'm very sober.

A.A.

So thank you, but not today, Satan.

Don: Did you just call me Satan?

Chelsea: [ Mutters indistinctly ]

Don: I'm not Satan, but I can get him here.

I know how to do it. -Chelsea: [ Sighs ] Okay, how?

Don: It involves ejaculating on parchment paper...

-Chelsea: I got to -- -Don: ...and making a circle of candles.

-Chelsea: [ Sighs ] -Don: There's a guy --

I got to get a priest over here -- a black priest.

Chelsea: Wha-- Unnecessary.

Don: Oh, a black priest can summon Satan,

but he's not a black man. He's a white man.

Chelsea: Stop saying "black priest."

Don: It's very confusing. You're not the first person

to have this problem, I'll tell you that right now.

Chelsea: Yeah, I got to go.

It turns out Chelsea does scare easily.

Do I just go left at the 19 grottos to get out?

Don: It's a lot harder than that to get out of here, sweetheart.

You're gonna need your wits about you,

you're gonna need to be wily,

and you're gonna need to be fast.

Go.

Smart.

Too smart.

??

Baxter: We thought it was game over for us,

but then I got a last-minute call

to show a $14 million listing in Bel Air.

Andrew: Unfortunately, I was in the middle of

a massive dump sesh and told Baxter to go without me.

Baxter: Gonna miss you, buddy,

but I'm gonna make the sale for both of us.

??

Brace yourself for this. -Ted: Okay.

Baxter: This is the master bathroom.

Ted: Wow. This is -- This is the master?

Baxter: No judgments. They could be a great couple.

-Ina: I love it. -Baxter: It's pretty great.

Ina: It's so big. Oh, my God.

Baxter: It's big, right? Yes.

See? Yeah. -Ted: She thinks it's big.

-Baxter: Cedar sauna. -Ted: Oh.

Ina: [ Screams ] Oh, my God!

Ted: [ Chuckling ] Wow. Wow.

Ina: Oh, my God, oppa.

It's like our own [speaks native language] you know?

Baxter: Realtor tip -- a scream equals a sale.

If you don't mind me asking, where'd you guys meet?

-Ted: Oh, God.

-Ina: We met at Club Konna. -Ted: Club Konna.

Ina: He came up to me, and I was like, "What do you do?"

And he said, "I'm a rich doctor."

Ted: Doctor. I didn't say "rich," but --

Ina: And I was like, "Oh, my God. I love doctors."

Ted: She just got really excited right away.

Baxter: Rich doctor? Gold-digging girlfriend?

Easy-peasy.

Ted: Oh, yeah. Yeah?

Ina: I'm like a tap-dancing mermaid.

Ted: Yeah!

Ina: Can I be your mermaid in here?

Ted: Oh, yeah. Oh, yeah.

Baxter: What a fun couple?

-Ina: Fun. Look at this. -Baxter: As you can see,

there's kind of a lounging -- -Ted: This is a shower?

Oh, yeah, yeah, yeah, yeah. You are so dirty.

Ina: I so dirty. Wash it. Wash my butt.

-Ted: Yeah. Oh, yeah. -Ina: Oh, my God.

Ted: Oh, God, what a dirty butt you got.

-Ina: I'm so dirty. -Ted: Yeah. Yeah.

Ina: Oh, my God! Okay.

Ted: Oh, yeah. Let's get that --

Ina: [ Speaks native language ]

Ted: Okay. Yeah.

Ina: [ Screaming ]

Ted: Oh, yeah! Oh, yeah!

[ Yelling ]

[ Both panting ]

Holy fuck.

Ina: Oh, my God.

I need to go check out the bedroom.

Ted: Oh, Jesus. Oh, my God.

-Baxter: [ Chuckling ] Okay. -Ted: She's amazing.

Baxter: Looks like this bathroom is --

-Ted: Yeah, this bathroom -- -Baxter: You could get used

to this, right? -Ted: No, this is not happening.

I don't have -- I don't have any money, dude.

Baxter: You don't have any money?

Ted: I'm a social studies teacher, you know?

I'm -- I'm just getting

the fucking best pussy I've ever gotten in my life.

Baxter: [ Sighs ]

Are you serious? We're done.

??

Victoria: A half-hour left to go,

and I find out Chelsea didn't snag DiMello.

I'm going in.

You never send a pawn to do a king's job.

Don: [ Snoring ]

Victoria: Uh...

Don: [ Grunts ]

-Victoria: Hi, there. -Don: Oh, yes. Okay.

You're here to audition for one of my productions?

-Victoria: Oh. -Don: All right. Good.

Uh, first things first, you're not gonna need the dress.

It's not in the show. Take off the dress, and let's get started.

Victoria: No, we're keeping on the dress.

I'm Victoria King.

I'm from Platinum Realty? -Don: Oh.

Victoria: You've met with some of my other associates.

Unfortunately, none of them want to work with you.

-Don: You're here to sell the house. -Victoria: I am.

Okay, I think we could sell this house

for $25 million with you in it.

-Don: Really? -Victoria: Yes.

Don: That's fantastic, because I'm not going anywhere.

-Victoria: I know. I-I heard. -Don: Look at you.

Look at the legs. Look at the legs.

Victoria: Don is an acquired taste,

like dirt or vomit or arsenic.

Nothing I can't handle. Okay.

Don: Listen, though, I have to tell you something

that's potentially a real problem.

It could kill the deal. -Victoria: [ Sighs ]

What is it? Just tell me. -Don: Some of the plumbing

is original to the house, and it's rusted out.

I'm talking all the way to the sewer line.

It's got roots coming up through the clay piping.

Victoria: Wait, if it's just the plumbing...

-Don: Yeah. -Victoria: ...I can fix that.

-Don: Really? -Victoria: No problem. Oh, yeah.

I'll have my contractor come here, for sure.

Don: Okay. Good. Ah, I was worried about that one.

I thought nobody's gonna want to touch this house

with the original plumbing. -Victoria: Easy fix.

Don: Oh, my God. Oh, you know what also?

I got a guy in a dungeon in the basement.

Victoria: [ Sighs ]

Don: He broke into the house back in 1981...

Victoria: Yeah.

Don: ...and I wanted to send a message to other burglars.

Victoria: To be honest, legally, I don't even want to know this, okay?

But I would suggest that you set him free.

Don: Aw, I don't want to do that.

Victoria: We're gonna have to get rid of this guy.

Don: Are you saying we're gonna kill this guy?

-Victoria: No. -Don: 'Cause the only reason

I'm asking is, if it's possible,

I'd like to stuff his head and put it on the wall.

Don: I've grown accustomed to the look of his face.

-Victoria: No. -Don: And all these years,

it'd be sad to say goodbye. -Victoria: Absolu--

That's a clear sign that you have killed him.

I can't sell that. -Don: Okay.

Victoria: All right? Besides, I don't want to be tied in with this.

Don: You really know your stuff.

Victoria: I'm telling you, I am gonna get this house sold.

Don: I want someone to have sex with me after I've died.

Victoria: What?!

Yes! I got the listing!

Can you taste that?

That is the partnership!

And bile. But mostly the partnership!

??

Victoria: This is it --

the culmination of my life's work

and years of sweat, blood, and vodka.

Baxter: We had two hours, and we didn't even make one sale.

Andrew: But it's not over yet.

Victoria: You guys shouldn't feel that bad that you lost.

-Chelsea: We didn't lose yet. -Baxter: He's yet to --

Victoria: Let's be realistic here.

Baxter: They've yet to add up the intangibles.

Victoria: Whose animal's at the top of the chart?

Amir: I swear, if you become partner,

I'm jumping out of the building.

-Victoria: Thank you. -Andrew: Well, we'll see.

??

Dean: [ Sighs, clears throat ]

Well.

Hello.

-Chelsea: Sir. -Dean: I have a speech.

When I founded this company so many years ago,

all I had was a dream,

a little pickax,

a regular-size pickax,

a $100 million loan from my father,

grit, determination,

and a box of cereal.

That cereal's gone now, but everything else remains.

I never thought I would have a partner.

I thought I would walk through this earth alone,

save only for the company

of the ghosts of those I have betrayed.

But things change, and I have decided,

yes, I will take a partner in this firm.

Time for the announcement.

[ Sighs ]

Amir. -Amir: Yes!

-Dean: Wait. -Amir: Yes! You suck!

You're fired, you dumb slut!

Go get your shit, and get the hell out of here!

No security! You go now!

Don't go back to your desk! Get the hell out of here!

[ Grunts ]

Dean: Amir, it's not you.

I mean, I had a bunch of reasons that I was gonna give,

but I think that was great.

That saved me a lot of time. -Victoria: Not necessary.

Dean: I got it, Victoria. That's -- It's not you.

Victoria: [ Giggles ]

Amir: [ Sobbing ]

Victoria: [ Laughing ]

Amir: Wait. Did I -- Did I lose before you did that, or --

Dean: Yes. You're like Pig-Pen.

You have this sort of mistaken cloud hanging around you.

-Chelsea: Yeah. -Amir: Bechieve.

-Dean: What is he saying? -Chelsea: "Bechieve."

It's his thing. It's really boring.

Victoria: "Believe" mixed with "achieve."

Dean: Well, that doesn't work at all.

-Victoria: No, that's not it. -Dean: It sounds like a food.

Chelsea.

-Chelsea: Hey. -Dean: You're young.

You're energetic. -Chelsea: Thank you.

Dean: You're plugged into the modern world.

-Chelsea: Yes. -Dean: Always on that phone.

Typing, typing, typing with your thumbs.

It's a wonder you haven't typed them away.

[ Laughter ]

Chelsea, I don't get electronic stuff.

It's weird to me. -Chelsea: Oh.

Dean: It's not wood, it's not leather, it's not animal hide.

-Chelsea: No. -Dean: What is it?

Ones, zeroes -- numbers? Boo!

Chelsea... -Chelsea: Yes?

Dean: [ Inhales deeply ] ...you will be...

the person... -Chelsea: Uh-huh?

Dean: ...not chosen as my partner.

Chelsea: That was really misleading.

Dean: I-I think I started the sentence

before I knew how it was going to end up.

I mean, I knew my intention. -Chelsea: Are you sure, though,

that you don't want someone, like, new and fresh

to lead us into the new millennium?

Dean: I thought about that,

and then I thought, "No, I don't want that."

-Andrew: Oh, my God! -Baxter: It's gonna be us.

-Andrew: We did it. -Baxter: It's us!

Dean: I'm moving my eyes over to...these guys.

One of you is named Baxter.

One of you is named Andrew.

Am I correct so far?

Baxter: Yes.

-Dean: Baxter. -Baxter: Yes?

Dean: Your hair confounds me.

How does it do that?

It would be too distracting.

Andrew. -Andrew: Daddy.

Dean: I keep forgetting your name,

and there's the "daddy" thing.

You're too unsettling.

I'm looking for a partner.

I'm not looking for two partners.

I'm looking for a partner.

Now, you can pretend that you're, together,

equaling one person.

Like two kids in a trench coat pretending to be a man.

Baxter: We've done that twice,

and it worked out in a sale both times.

Dean: The two you together -- not my partner.

Baxter: [ Sighs ]

Amir: Fuck no. It's Victoria.

Victoria: It's mine! Everything's mine!

-Dean: Victoria. -Victoria: Yes?

-Dean: Sit down. -Victoria: Dean, let me begin

by saying this was a great decision,

and I want everyone to know here that I'm going to

treat you fairly as the new partner.

Will you get fired? [ Inhales sharply ]

I don't know, but I'll think about it.

And I'll think about it a long time.

And as your new partner,

I just want you to know I am here to support you

and stand next to you as we embark this journey together.

Dean: Hm. It's not you, Victoria.

-Victoria: What? -Dean: It's not you.

You should sit down before you literally fall.

Amir: Oh, no. Oh, no.

Chelsea: Victoria, are your eyes bleeding?

-Dean: Her legs don't work. -Victoria: I'm not breathing.

I don't think -- -Dean: All right.

Victoria: I don't think I'm breathing.

[ Crying ] What? What? No.

No, no, no. What?

Amir: If she's not partner and neither of us are partner,

who the hell is partner?

-Dean: I'm about to tell you. -Victoria: What?

Dean: please say hello to my new partner at Platinum,

Glenn Bouchard.

-Andrew: What? -Chelsea: What?

??

Victoria: What?

Dean: Glenn is now the bishop while you all remain pawns.

Chelsea: But [stammers] this doesn't make sense.

Glenn: What's up, fellow brokers?

Baxter: But he isn't even a broker.

Andrew: And he's Glenn!

Dean: [ Chuckles ]

Amir: I didn't see this coming. I didn't see this coming.

How did I not see this coming?!

[ All shouting indistinctly ]

Chelsea: This is ridiculous.

[ Shouting continues ]

You're a piece of shit.

Andrew: Bullshit! Bullshit! Bullshit!

Glenn: Dean told me I was partner, I blacked out,

and when I came to, I looked sexy.

Welcome to the age of new Glenn.

??

Next season on "Bajillion Dollar Properties"...

This is partner Glenn, and partner Glenn is different.

Andrew: Classic story of little guy

making it big. -Baxter: Big.

Dean: We are nominated for best brokerage.

We're up against our old foes, Infinity,

and I want to crush them.

Man: Oh, thank you, trophy. Oh, thank you, trophy.

Xavier: You are both sired.

Man: I like that. You got food in the number-two room.

Woman: I've got a punchable face. Everyone says it.

Man: I'm all about humanitarian work...

-Victoria: Mm-hmm. -Man: ...and eating pussy.

-Victoria: Yeah. -All: Ahhhhhhhhhhh.

Man: So he went off on my foot for like a half an hour.

Woman: Wood and then also not wood.

-Dean: No! -Chelsea: Whoa!

Dean: Predators.

Woman: That's the third one today.

Man: You trying to fuck my mom, motherfucker?

-Amir: Jesus Christ. -Man: [ Vomits ]

Man: [ Laughs ] I can't wait.

[ Grunting ]

Dean: We will go to those Real Estate Awards.

We will win that Diamond Deal Maker.

Victory! -Glenn: Yeah!

Man: And cut, print.

Repair and Synchronization by Easy Subtitles Synchronizer 1.0.0.0

Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.